@@ -1,6 +1,6 @@
 from django.conf import settings
 
-from csp import build_policy
+from csp.utils import build_policy
 
 
 class CSPMiddleware(object):
@@ -17,17 +17,22 @@ class CSPMiddleware(object):
         if getattr(response, '_csp_exempt', False):
             return response
 
-        header = 'X-Content-Security-Policy'
+        # Check for ignored path prefix.
+        prefixes = getattr(settings, 'CSP_EXCLUDE_URL_PREFIXES', ('/admin',))
+        if request.path_info.startswith(prefixes):
+            return response
+
+        header = 'Content-Security-Policy'
         if getattr(settings, 'CSP_REPORT_ONLY', False):
-            header = 'X-Content-Security-Policy-Report-Only'
+            header += '-Report-Only'
 
         if header in response:
             # Don't overwrite existing headers.
             return response
 
-        if getattr(settings, 'CSP_POLICY_URI', False):
-            policy = 'policy-uri ' + settings.CSP_POLICY_URI
-        else:
-            policy = build_policy()
-        response[header] = policy
+        config = getattr(response, '_csp_config', None)
+        update = getattr(response, '_csp_update', None)
+        replace = getattr(response, '_csp_replace', None)
+        response[header] = build_policy(config=config, update=update,
+                                        replace=replace)
         return response
